@@ -6,11 +6,11 @@ use fil_actors_runtime::{
     actor_error, wasm_trampoline, ActorError, BURNT_FUNDS_ACTOR_ADDR, EXPECTED_LEADERS_PER_EPOCH,
     STORAGE_POWER_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::bigint::bigint_ser::BigIntDe;
 use fvm_shared::bigint::{Integer, Sign};
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::sector::StoragePower;
 use fvm_shared::{MethodNum, METHOD_CONSTRUCTOR, METHOD_SEND};
 use log::{error, warn};
@@ -66,7 +66,7 @@ impl Actor {
             Ok(())
         } else {
             Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "argument should not be nil"
             ))
         }
@@ -94,21 +94,21 @@ impl Actor {
         let prior_balance = rt.current_balance();
         if params.penalty.sign() == Sign::Minus {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "negative penalty {}",
                 params.penalty
             ));
         }
         if params.gas_reward.sign() == Sign::Minus {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "negative gas reward {}",
                 params.gas_reward
             ));
         }
         if prior_balance < params.gas_reward {
             return Err(actor_error!(
-                ErrIllegalState,
+                USR_ILLEGAL_STATE,
                 "actor current balance {} insufficient to pay gas reward {}",
                 prior_balance,
                 params.gas_reward
@@ -116,7 +116,7 @@ impl Actor {
         }
         if params.win_count <= 0 {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "invalid win count {}",
                 params.win_count
             ));
@@ -124,7 +124,7 @@ impl Actor {
 
         let miner_addr = rt
             .resolve_address(&params.miner)
-            .ok_or_else(|| actor_error!(ErrNotFound, "failed to resolve given owner address"))?;
+            .ok_or_else(|| actor_error!(USR_NOT_FOUND, "failed to resolve given owner address"))?;
 
         let penalty: TokenAmount = &params.penalty * PENALTY_MULTIPLIER;
 
@@ -143,7 +143,7 @@ impl Actor {
                 block_reward = &total_reward - &params.gas_reward;
                 if block_reward.is_negative() {
                     return Err(actor_error!(
-                        ErrIllegalState,
+                        USR_ILLEGAL_STATE,
                         "programming error, block reward {} below zero",
                         block_reward
                     ));
@@ -157,7 +157,7 @@ impl Actor {
         // * as they treat panics as an exit code. Revisit this.
         if total_reward > prior_balance {
             return Err(actor_error!(
-                ErrIllegalState,
+                USR_ILLEGAL_STATE,
                 "reward {} exceeds balance {}",
                 total_reward,
                 prior_balance
@@ -227,7 +227,7 @@ impl Actor {
     {
         rt.validate_immediate_caller_is(std::iter::once(&*STORAGE_POWER_ACTOR_ADDR))?;
         let curr_realized_power = curr_realized_power
-            .ok_or_else(|| actor_error!(ErrIllegalArgument, "argument cannot be None"))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_ARGUMENT, "argument cannot be None"))?;
 
         rt.transaction(|st: &mut State, rt| {
             let prev = st.epoch;
@@ -275,7 +275,7 @@ impl ActorCode for Actor {
                 Self::update_network_kpi(rt, param.map(|v| v.0))?;
                 Ok(RawBytes::default())
             }
-            None => Err(actor_error!(SysErrInvalidMethod, "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD, "Invalid method")),
         }
     }
 }
